@@ -3,9 +3,9 @@
 #'
 #' Determines the heading between spatial points.
 #'
-#' @param from The starting position; an object of class SpatVector
+#' @param from The starting position; an object of class `SpatVector`.
 #'
-#' @param to The ending position;  an object of class SpatVector
+#' @param to The ending position; an object of class `SpatVector`.
 #'
 #' @return The heading between the points, in degrees.
 #'
@@ -15,8 +15,11 @@
 #'
 #' @examples
 #' library(terra)
-#' if (require("CircStats")) {
-#' N <- 10L                # number of agents
+#'
+#' origDTThreads <- data.table::setDTthreads(2L)
+#' origNcpus <- options(Ncpus = 2L)
+#'
+#' N <- 10L                       # number of agents
 #' x1 <- stats::runif(N, -50, 50) # previous X location
 #' y1 <- stats::runif(N, -50, 50) # previous Y location
 #' x0 <- stats::rnorm(N, x1, 5)   # current X location
@@ -40,15 +43,17 @@
 #' prev <- matrix(c(x1, y1), ncol = 2, dimnames = list(NULL, c("x","y")))
 #' curr <- terra::vect(cbind(x = x0, y = y0))
 #' heading(prev, curr)
-#' }
+#'
+#' # clean up
+#' data.table::setDTthreads(origDTThreads)
+#' options(Ncpus = origNcpus)
 #'
 heading <- function(from, to) {
-  .requireNamespace("CircStats")
   from <- coords(from)
   to <- coords(to)
   ys <- to[, 2] - from[, 2]
   xs <- to[, 1] - from[, 1]
-  heading <- CircStats::deg(atan(xs / ys)) ## 0/0 produces NaN; correct this below
+  heading <- deg2(atan(xs / ys)) ## 0/0 produces NaN; correct this below
   heading[xs == 0 & ys == 0] <- 0
   ys <- (ys < 0)
   heading[(ys) & (xs) < 0] <- heading[(ys) & (xs) < 0] - 180
@@ -57,7 +62,16 @@ heading <- function(from, to) {
 }
 
 coords <- function(crds) {
-  if (inherits(crds, "SpatVector")) {
+  if (is.matrix(crds)) {
+    if (isS4(crds)) {
+      crds <- crds@.Data[, 1:2, drop = FALSE]
+      if (!identical(colnames(crds), xycolNames))
+        colnames(crds) <- xycolNames
+    } else {
+      crds <- crds[, 1:2, drop = FALSE]
+    }
+
+  } else if (inherits(crds, "SpatVector")) {
     .requireNamespace("terra")
     crds <- terra::crds(crds)
   } else if (inherits(crds, "sf")) {
@@ -72,14 +86,22 @@ coords <- function(crds) {
 }
 
 `coords<-` <- function(obj, value) {
-  if (inherits(obj, "SpatVector")) {
+  if (is.matrix(obj)) {
+    if (isS4(obj)) {
+      obj@.Data[, 1:2] <- value
+    } else {
+      obj[, 1:2] <- value
+    }
+  } else if (inherits(obj, "SpatVector")) {
     .requireNamespace("terra")
-    crdsdf <- data.frame(value, as.data.frame(coords(obj)))
-    colnames(crdsdf) <- c("x", "y", "x1", "y1")
-    obj <- terra::vect(crdsdf, geom = c("x", "y"))
+    crdsdf <- data.frame(value, as.data.frame(obj))
+    if (!identical(colnames(crdsdf)[1:2], xycolNames)) {
+      colnames(crdsdf)[1:2] <- xycolNames
+    }
+    obj <- terra::vect(crdsdf, geom = xycolNames)
   } else if (inherits(obj, "sf")) {
     .requireNamespace("sf")
-    obj2 <- sf::st_as_sfc(sf::st_as_sf(as.data.frame(value), coords = c("x", "y")))
+    obj2 <- sf::st_as_sfc(sf::st_as_sf(as.data.frame(value), coords = xycolNames))
     obj <- sf::st_set_geometry(obj, value = obj2)
     obj
   } else if (inherits(obj, "Spatial")) {
@@ -89,3 +111,6 @@ coords <- function(crds) {
 
   obj
 }
+
+x1y1colNames <- c("x1", "y1")
+xycolNames <- c("x", "y")
