@@ -1,31 +1,22 @@
 test_that("splitRaster and mergeRaster work on small in-memory rasters", {
-  # withr::local_package("reproducible")
-  withr::local_package("tools")
-  rastDF <- needTerraAndRaster() #
+  testInit("tools")
+  rastDF <- needTerraAndRaster()
   testFiles = data.frame(pkg = c("raster", "terra"),
                          testFile = c("external/rlogo.grd", "ex/logo.tif"))
   rastDF <- merge(testFiles, rastDF)
 
-  data.table::setDTthreads(1)
-
   for (ii in seq(NROW(rastDF))) {
     pkg <- rastDF$pkg[ii]
     cls <- rastDF$class[ii]
     read <- eval(parse(text = rastDF$read[ii]))
     extFun <- eval(parse(text = rastDF$ext[ii]))
+    readStk <- eval(parse(text = rastDF$stack[ii]))
 
     testFile <- system.file(rastDF$testFile[ii], package = pkg)
 
     withr::local_package(pkg)
-    # withr::local_options(reproducible.rasterRead = read)
-
-    owd <- getwd()
-    on.exit({
-      setwd(owd)
-    }, add = TRUE)
-
-    tmpdir <- file.path(tempdir(), "splitRaster-test", pkg) |> checkPath(create = TRUE)
-    setwd(tmpdir)
+    tmpdir2 <- file.path(tmpdir, "splitRaster-test", pkg) |> checkPath(create = TRUE)
+    setwd(tmpdir2)
 
     b <- read(testFile)
     r <- b[[1]] # use first layer only
@@ -38,12 +29,12 @@ test_that("splitRaster and mergeRaster work on small in-memory rasters", {
     extnt(r) <- extnt(xmin(r) - 30, xmax(r) - 30, ymin(r) - 20, ymax(r) - 20)
 
     # no buffer
-    y0 <- splitRaster(r, nx, ny, path = file.path(tmpdir, "red"))
+    y0 <- splitRaster(r, nx, ny, path = file.path(tmpdir2, "red"))
     expect_equal(class(y0), "list")
     expect_false(unique(unlist(lapply(y0, inMemory))))
 
     for (i in 1:12) {
-      expect_true(file.exists(file.path(tmpdir, "red", paste0("red_tile", i, ".tif"))))
+      expect_true(file.exists(file.path(tmpdir2, "red", paste0("red_tile", i, ".tif"))))
     }
 
     xextents <- c()
@@ -60,35 +51,37 @@ test_that("splitRaster and mergeRaster work on small in-memory rasters", {
     expect_equal(unique(lapply(y0, crs))[[1]], crs(r))
 
     m0 <- mergeRaster(y0)
-    expect_equal(dim(m0), dim(r))
-    expect_equal(extnt(m0), extnt(r))
-    expect_equal(res(m0), res(r))
-    expect_equal(max(values(m0)), max(values(r)))
-    expect_equal(min(values(m0)), min(values(r)))
 
-    # as a stack/brick
-    if (requireNamespace("purrr", quietly = TRUE)) {
-      if (pkg == "raster") {
-        ## ensure the raster method for as.list used (instead of base version)
-        asRasterList <- selectMethod("as.list", "Raster")
-        ys0 <- lapply(purrr::transpose(lapply(X = asRasterList(b),
-                                              FUN = splitRaster, nx = nx, ny = ny)),
-                      raster::stack)
-      } else if (pkg == "terra") {
-        ys0 <- lapply(purrr::transpose(lapply(X = as.list(b),
-                                              FUN = splitRaster, nx = nx, ny = ny)),
-                      terra::rast)
-      }
-      ms0 <- mergeRaster(ys0)
-      expect_identical(names(ms0), names(ys0[[1]]))
+    if (is(m0, "Raster")) {
+      expect_true(raster::compareRaster(m0, r, extent = TRUE, rowcol = TRUE, crs = TRUE, res = TRUE,
+                  orig = TRUE, rotation = TRUE, values = TRUE, stopiffalse = FALSE))
+      expect_equal(max(values(m0)), max(values(r)))
+      expect_equal(min(values(m0)), min(values(r)))
+    } else {
+      expect_true(terra::compareGeom(m0, r, crs = TRUE, ext = TRUE, rowcol = TRUE, res = TRUE,
+                                     stopOnError = FALSE))
+      expect_equal(max(values(m0)), max(values(r)))
+      expect_equal(min(values(m0)), min(values(r)))
     }
 
+    # as a stack/brick
+    sr <- splitRaster(b, nx = nx, ny = ny)
+    # if (pkg == "raster") {
+    ## ensure the raster method for as.list used (instead of base version)
+    ys0 <- lapply(sr, readStk)
+    # } else if (pkg == "terra") {
+    #   ys0 <- lapply(sr, terra::rast)
+    # }
+    ms0 <- mergeRaster(ys0)
+    expect_identical(names(ms0), names(ys0[[1]]))
+    #}
+
     # with buffer (integer pixels) and with specified path
-    y1 <- splitRaster(r, nx, ny, c(3L, 4L), path = file.path(tmpdir, "red1"))
+    y1 <- splitRaster(r, nx, ny, c(3L, 4L), path = file.path(tmpdir2, "red1"))
     expect_false(unique(unlist(lapply(y1, inMemory))))
 
     for (i in 1:12) {
-      expect_true(file.exists(file.path(tmpdir, "red1", paste0("red_tile", i, ".tif"))))
+      expect_true(file.exists(file.path(tmpdir2, "red1", paste0("red_tile", i, ".tif"))))
     }
 
     xextents <- c()
@@ -105,11 +98,18 @@ test_that("splitRaster and mergeRaster work on small in-memory rasters", {
     expect_equal(unique(lapply(y1, crs))[[1]], crs(r))
 
     m1 <- mergeRaster(y1)
-    expect_equal(dim(m1), dim(r))
-    expect_equal(extnt(m1), extnt(r))
-    expect_equal(res(m1), res(r))
-    expect_equal(max(values(m1)), max(values(r)))
-    expect_equal(min(values(m1)), min(values(r)))
+
+    if (is(m1, "Raster")) {
+      expect_true(raster::compareRaster(m1, r, extent = TRUE, rowcol = TRUE, crs = TRUE, res = TRUE,
+                                        orig = TRUE, rotation = TRUE, values = TRUE, stopiffalse = FALSE))
+      expect_equal(max(values(m1)), max(values(r)))
+      expect_equal(min(values(m1)), min(values(r)))
+    } else {
+      expect_true(terra::compareGeom(m1, r, crs = TRUE, ext = TRUE, rowcol = TRUE, res = TRUE,
+                                     stopOnError = FALSE))
+      expect_equal(max(values(m1)), max(values(r)))
+      expect_equal(min(values(m1)), min(values(r)))
+    }
 
     # with no path specified, file is in memory
     y1 <- splitRaster(r, nx, ny, c(3L, 4L))
@@ -119,7 +119,7 @@ test_that("splitRaster and mergeRaster work on small in-memory rasters", {
     }
 
     # with buffer (proportion of cells)
-    y2 <- splitRaster(r, nx, ny, c(0.5, 0.3), path = file.path(tmpdir, "red2"))
+    y2 <- splitRaster(r, nx, ny, c(0.5, 0.3), path = file.path(tmpdir2, "red2"))
     xextents <- c()
     yextents <- c()
     for (i in seq_along(y2)) {
@@ -134,11 +134,18 @@ test_that("splitRaster and mergeRaster work on small in-memory rasters", {
     expect_equal(unique(lapply(y2, crs))[[1]], crs(r))
 
     m2 <- mergeRaster(y2)
-    expect_equal(dim(m2), dim(r))
-    expect_equal(extnt(m2), extnt(r))
-    expect_equal(res(m2), res(r))
-    expect_equal(max(values(m2)), max(values(r)))
-    expect_equal(min(values(m2)), min(values(r)))
+
+    if (is(m2, "Raster")) {
+      expect_true(raster::compareRaster(m2, r, extent = TRUE, rowcol = TRUE, crs = TRUE, res = TRUE,
+                                        orig = TRUE, rotation = TRUE, values = TRUE, stopiffalse = FALSE))
+      expect_equal(max(values(m2)), max(values(r)))
+      expect_equal(min(values(m2)), min(values(r)))
+    } else {
+      expect_true(terra::compareGeom(m2, r, crs = TRUE, ext = TRUE, rowcol = TRUE, res = TRUE,
+                                     stopOnError = FALSE))
+      expect_equal(max(values(m2)), max(values(r)))
+      expect_equal(min(values(m2)), min(values(r)))
+    }
 
     # different raster resolutions
     r1 <- r
@@ -183,9 +190,7 @@ test_that("splitRaster and mergeRaster work on small in-memory rasters", {
       expect_true(terra::is.int(y4[[1]]))
     }
 
-    expect_warning({
-      y5 <- splitRaster(r, nx, ny, rType = "INT") # INT invalid; defaults to INT4S
-    }, "INT is not a valid datatype")
+    y5 <- splitRaster(r, nx, ny, rType = "INT4S")
     if (pkg == "raster") {
       expect_identical(reproducible::dataType2(y5[[1]]), "INT4S")
     } else if (pkg == "terra") {
@@ -193,7 +198,7 @@ test_that("splitRaster and mergeRaster work on small in-memory rasters", {
       expect_true(terra::is.int(y5[[1]]))
     }
 
-    y6 <- splitRaster(r, nx, ny) # defaults to FLT4S
+    y6 <- splitRaster(r, nx, ny) ## defaults to FLT4S
     if (pkg == "raster") {
       expect_identical(reproducible::dataType2(y6[[1]]), "FLT4S")
     } else if (pkg == "terra") {
@@ -202,31 +207,21 @@ test_that("splitRaster and mergeRaster work on small in-memory rasters", {
     }
 
     ## use different file extensions
-    y7 <- splitRaster(r, nx, ny, path = tmpdir, fExt = ".grd")
-    y8 <- splitRaster(r, nx, ny, path = tmpdir, fExt = ".tif")
+    y7 <- splitRaster(r, nx, ny, path = tmpdir2, fExt = ".grd")
+    y8 <- splitRaster(r, nx, ny, path = tmpdir2, fExt = ".tif")
     if (requireNamespace("tools", quietly = TRUE)) {
       expect_true(all(tools::file_ext(reproducible::Filenames(y7[[1]])) %in% c("grd", "gri")))
       expect_true(tools::file_ext(reproducible::Filenames(y8[[1]])) == "tif")
     }
-
-    setwd(owd)
   }
-
-  unlink(dirname(tmpdir), recursive = TRUE)
 })
 
 test_that("splitRaster works in parallel", {
   skip_on_cran()
   skip_on_ci()
-  skip_if_not_installed("snow") # needed for beginCluster
-  skip_if_not_installed("raster")
+  testInit(c("raster", "snow"))
   skip_if_not(interactive())
 
-  tmpdir <- file.path(tempdir(), "splitRaster-test-parallel", basename(tempfile())) |>
-    checkPath(create = TRUE)
-
-  on.exit(unlink(tmpdir, recursive = TRUE), add = TRUE)
-
   # b <- raster::brick(system.file("external/rlogo.grd", package = "raster"))
   b <- raster::raster(system.file("ex/logo.tif", package = "terra"))
   r <- b[[1]] # use first layer only
@@ -240,7 +235,7 @@ test_that("splitRaster works in parallel", {
 
   # test parallel cropping
   n <- pmin(parallel::detectCores(), 4) # use up to 4 cores
-  raster::beginCluster(n)
+  raster::beginCluster(n, type = "PSOCK")
   on.exit(raster::endCluster(), add = TRUE)
 
   cl <- raster::getCluster()
@@ -266,29 +261,27 @@ test_that("splitRaster works in parallel", {
   expect_equal(unique(lapply(y11, crs))[[1]], crs(r))
 
   m11 <- mergeRaster(y11)
-  expect_equal(dim(m11), dim(r))
-  expect_equal(raster::extent(m11), raster::extent(r))
-  expect_equal(names(m11), names(r))
-  expect_equal(res(m11), res(r))
-  expect_equal(max(values(m11)), max(values(r)))
-  expect_equal(min(values(m11)), min(values(r)))
+
+  if (is(m11, "Raster")) {
+    expect_true(raster::compareRaster(m11, r, extent = TRUE, rowcol = TRUE, crs = TRUE, res = TRUE,
+                                      orig = TRUE, rotation = TRUE, values = TRUE, stopiffalse = FALSE))
+    expect_equal(max(values(m11)), max(values(r)))
+    expect_equal(min(values(m11)), min(values(r)))
+  } else {
+    expect_true(terra::compareGeom(m11, r, crs = TRUE, ext = TRUE, rowcol = TRUE, res = TRUE,
+                                   stopOnError = FALSE))
+    expect_equal(max(values(m11)), max(values(r)))
+    expect_equal(min(values(m11)), min(values(r)))
+  }
+
   raster::endCluster()
 })
 
 test_that("splitRaster and mergeRaster work on large on-disk rasters", {
   skip_on_cran()
   skip_on_ci()
-  #skip_if_not(interactive() && Sys.info()[["user"]] %in% c("achubaty", "emcintir"))
   skip("this is a BIG test!")
-
-  library(reproducible)
-  library(terra)
-
-  tmpdir <- file.path(tempdir(), "splitRaster-test-large") |> checkPath(create = TRUE)
-
-  on.exit({
-    unlink(tmpdir, recursive = TRUE)
-  }, add = TRUE)
+  testInit(c("terra"))
 
   ## use a large raster (1.3 GB)
   url <- paste0("https://ftp.maps.canada.ca/pub/nrcan_rncan/Land-cover_Couverture-du-sol/",
@@ -342,10 +335,15 @@ test_that("splitRaster and mergeRaster work on large on-disk rasters", {
   expect_equal(ext(r), u1)
 
   m1 <- mergeRaster(s1) # takes a while to run...
-  expect_equal(dim(m1), dim(r))
-  expect_equal(ext(m1), ext(r))
-  expect_equal(names(m1), names(r))
-  expect_equal(res(m1), res(r))
-  # expect_equal(max(values(m1)), max(values(r)))
-  # expect_equal(min(values(m1)), min(values(r)))
+  if (is(m1, "Raster")) {
+    expect_true(raster::compareRaster(m1, r, extent = TRUE, rowcol = TRUE, crs = TRUE, res = TRUE,
+                                      orig = TRUE, rotation = TRUE, values = TRUE, stopiffalse = FALSE))
+    expect_equal(max(values(m1)), max(values(r)))
+    expect_equal(min(values(m1)), min(values(r)))
+  } else {
+    expect_true(terra::compareGeom(m1, r, crs = TRUE, ext = TRUE, rowcol = TRUE, res = TRUE,
+                                   stopOnError = FALSE))
+    expect_equal(max(values(m1)), max(values(r)))
+    expect_equal(min(values(m1)), min(values(r)))
+  }
 })
